.. _models:

Models
======

- Radiative models:
    - `naima.models.Synchrotron`
    - `naima.models.InverseCompton`
    - `naima.models.PionDecay`
    - `naima.models.Bremsstrahlung`
- Functional models:
    - `naima.models.PowerLaw`
    - `naima.models.ExponentialCutoffPowerLaw`
    - `naima.models.BrokenPowerLaw`
    - `naima.models.ExponentialCutoffBrokenPowerLaw`
    - `naima.models.LogParabola`
- Table models:
    - `naima.models.TableModel`

API
---

.. automodule:: naima.models
    :members: Synchrotron, InverseCompton, Bremsstrahlung, PionDecay, PowerLaw,
                BrokenPowerLaw, ExponentialCutoffBrokenPowerLaw, LogParabola,
                TableModel
    :inherited-members:
